'use strict';

Object.defineProperty(exports, '__esModule', {
  value: true
});
exports['default'] = createAction;
var id = 0;

var identity = function identity(arg) {
  return arg;
};

function createAction(name) {
  var mapper = arguments.length <= 1 || arguments[1] === undefined ? identity : arguments[1];

  if (typeof name === 'function') {
    mapper = name;
    name = undefined;
  }

  if (typeof mapper !== 'function') {
    mapper = identity;
  }

  var action = {
    id: ++id,
    type: '[' + id + ']' + (name ? ' ' + name : '')
  };

  var actionStores = undefined;

  function setupPayload(payload) {
    return {
      id: action.id,
      type: action.type,
      payload: payload
    };
  }

  function actionCreator() {
    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    var payloaded = setupPayload(mapper.apply(undefined, args));

    if (Array.isArray(actionStores)) {
      return actionStores.map(function (store) {
        return store.dispatch(payloaded);
      });
    } else if (actionStores) {
      return actionStores.dispatch(payloaded);
    } else {
      return payloaded;
    }
  }

  actionCreator.toString = function () {
    return action.id;
  };

  actionCreator.bindTo = function (stores) {
    actionStores = stores;
    return actionCreator;
  };

  return actionCreator;
}

;
module.exports = exports['default'];