'use strict';

Object.defineProperty(exports, '__esModule', {
  value: true
});
exports['default'] = createReducer;

function createReducer(handlers, defaultState) {
  if (handlers === undefined) handlers = {};

  var opts = {
    payload: true
  };

  function on(actionCreator, handler) {
    handlers[actionCreator.toString()] = handler;
  }

  function off(actionCreator) {
    delete handlers[actionCreator.toString()];
  }

  function options(newOpts) {
    Object.keys(newOpts).forEach(function (name) {
      return opts[name] = newOpts[name];
    });
  }

  if (typeof handlers === 'function') {
    var factory = handlers;
    handlers = {};
    factory(on);
  }

  function reduce(state, action) {
    if (state === undefined) state = defaultState;

    if (handlers[action.id]) {
      return handlers[action.id](state, opts.payload ? action.payload : action);
    } else {
      return state;
    }
  };

  reduce.on = on;
  reduce.off = off;
  reduce.options = options;

  return reduce;
}

;
module.exports = exports['default'];